@@ -222,7 +222,7 @@ class IMAPRepository(BaseRepository):
         return self.getconfint('remoteport', None)
 
     def getipv6(self):
-        return self.getconfboolean('ipv6', False)
+        return self.getconfboolean('ipv6', None)
 
     def getssl(self):
         return self.getconfboolean('ssl', True)
