@@ -1,5 +1,5 @@
 # UI base class
-# Copyright (C) 2002-2015 John Goerzen & contributors
+# Copyright (C) 2002-2016 John Goerzen & contributors.
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
 import logging
+import logging.handlers
 import re
 import time
 import sys
@@ -23,11 +24,12 @@ import traceback
 import threading
 try:
     from Queue import Queue
-except ImportError: #python3
+except ImportError: # python3
     from queue import Queue
 from collections import deque
-from offlineimap.error import OfflineImapError
+
 import offlineimap
+from offlineimap.error import OfflineImapError
 
 debugtypes = {'':'Other offlineimap related sync messages',
               'imap': 'IMAP protocol debugging',
@@ -91,10 +93,22 @@ class UIBase(object):
         self.logger.info(offlineimap.banner)
         return ch
 
+    def setup_sysloghandler(self):
+        """Backend specific syslog handler."""
+
+        # create syslog handler
+        ch = logging.handlers.SysLogHandler('/dev/log')
+        # create formatter and add it to the handlers
+        self.formatter = logging.Formatter("%(message)s")
+        ch.setFormatter(self.formatter)
+        # add the handlers to the logger
+        self.logger.addHandler(ch)
+
     def setlogfile(self, logfile):
         """Create file handler which logs to file."""
 
         fh = logging.FileHandler(logfile, 'at')
+        #fh.setLevel(logging.DEBUG)
         file_formatter = logging.Formatter("%(asctime)s %(levelname)s: "
             "%(message)s", '%Y-%m-%d %H:%M:%S')
         fh.setFormatter(file_formatter)
@@ -102,9 +116,11 @@ class UIBase(object):
         # write out more verbose initial info blurb on the log file
         p_ver = ".".join([str(x) for x in sys.version_info[0:3]])
         msg = "OfflineImap %s starting...\n  Python: %s Platform: %s\n  "\
-              "Args: %s"% (offlineimap.__bigversion__, p_ver, sys.platform,
+              "Args: %s"% (offlineimap.__version__, p_ver, sys.platform,
                             " ".join(sys.argv))
-        self.logger.info(msg)
+        record = logging.LogRecord('OfflineImap', logging.INFO, __file__,
+                                   None, msg, None, None)
+        fh.emit(record)
 
     def _msg(self, msg):
         """Display a message."""
@@ -133,7 +149,7 @@ class UIBase(object):
         of the sync run when offlineiamp exits. It is recommended to
         always pass in exceptions if possible, so we can give the user
         the best debugging info.
-        
+
         We are always pushing tracebacks to the exception queue to
         make them to be output at the end of the run to allow users
         pass sensible diagnostics to the developers or to solve
@@ -145,9 +161,9 @@ class UIBase(object):
                "repo %s")
         """
         if msg:
-            self.logger.error("ERROR: %s\n  %s" % (msg, exc))
+            self.logger.error("ERROR: %s\n  %s"% (msg, exc))
         else:
-            self.logger.error("ERROR: %s" % (exc))
+            self.logger.error("ERROR: %s"% (exc))
 
         instant_traceback = exc_traceback
         if not self.debuglist:
@@ -165,8 +181,8 @@ class UIBase(object):
         if cur_thread in self.threadaccounts:
             # was already associated with an old account, update info
             self.debug('thread', "Register thread '%s' (previously '%s', now "
-                    "'%s')" % (cur_thread.getName(),
-                               self.getthreadaccount(cur_thread), account))
+                    "'%s')"% (cur_thread.getName(),
+                              self.getthreadaccount(cur_thread), account))
         else:
             self.debug('thread', "Register new thread '%s' (account '%s')"%
                 (cur_thread.getName(), account))
@@ -177,7 +193,7 @@ class UIBase(object):
 
         if thr in self.threadaccounts:
             del self.threadaccounts[thr]
-        self.debug('thread', "Unregister thread '%s'" % thr.getName())
+        self.debug('thread', "Unregister thread '%s'"% thr.getName())
 
     def getthreadaccount(self, thr=None):
         """Get Account() for a thread (current if None)
@@ -295,7 +311,7 @@ class UIBase(object):
         create the application window here."""
         pass
 
-    def connecting(self, hostname, port):
+    def connecting(self, reposname, hostname, port):
         """Log 'Establishing connection to'."""
 
         if not self.logger.isEnabledFor(logging.INFO): return
@@ -304,13 +320,14 @@ class UIBase(object):
         port = "%s"% port if port else ''
         if hostname:
             displaystr = ' to %s:%s' % (hostname, port)
-        self.logger.info("Establishing connection%s" % displaystr)
+        self.logger.info("Establishing connection%s (%s)"%
+            (displaystr, reposname))
 
     def acct(self, account):
         """Output that we start syncing an account (and start counting)."""
 
         self.acct_startimes[account] = time.time()
-        self.logger.info("*** Processing account %s" % account)
+        self.logger.info("*** Processing account %s"% account)
 
     def acctdone(self, account):
         """Output that we finished syncing an account (in which time)."""
@@ -370,9 +387,16 @@ class UIBase(object):
                 self.getnicename(sr), srcfolder,
                 self.getnicename(dr), dstfolder))
 
+    def ignorecopyingmessage(self, uid, src, destfolder):
+        """Output a log line stating which message is ignored."""
+
+        self.logger.info("IGNORED: Copy message UID %s %s:%s -> %s"% (
+                uid, src.repository, src, destfolder.repository))
+
     def copyingmessage(self, uid, num, num_to_copy, src, destfolder):
-        """Output a log line stating which message we copy"""
-        self.logger.info("Copy message %s (%d of %d) %s:%s -> %s" % (
+        """Output a log line stating which message we copy."""
+
+        self.logger.info("Copy message UID %s (%d/%d) %s:%s -> %s"% (
                 uid, num, num_to_copy, src.repository, src,
                 destfolder.repository))
 
@@ -430,7 +454,7 @@ class UIBase(object):
                         #TODO: Debug and make below working, it hangs Gmail
                         #res_type, response = conn.id((
                         #    'name', offlineimap.__productname__,
-                        #    'version', offlineimap.__bigversion__))
+                        #    'version', offlineimap.__version__))
                         #self._msg("Server ID: %s %s" % (res_type, response[0]))
                     self._msg("Server welcome string: %s" % str(conn.welcome))
                     self._msg("Server capabilities: %s\n" % str(conn.capabilities))
